@@ -5,8 +5,8 @@ import uuid
 from json import JSONDecodeError, JSONDecoder  # noqa
 from typing import Any, IO
 
+from dimtim.interfaces import Serializable
 from dimtim.utils import duration, timezone
-from dimtim.utils.serializable import Serializable
 
 __all__ = [
     'dump', 'dumps', 'load', 'loads', 'JSONEncoder', 'JSONDecoder', 'JSONDecodeError'
