@@ -1,5 +1,6 @@
 import re
 import unicodedata
+from typing import Optional
 
 
 def slugify(value: str, allow_unicode: bool = False):
@@ -46,3 +47,21 @@ def format_size(size: int):
         return f'{size / GIGABYTE:.2f} Gb'
     if size < PETABYTE:
         return f'{size / TERABYTE:.2f} Tb'
+
+
+def normalize_email(email: str) -> Optional[str]:
+    try:
+        email_name, domain_part = email.strip().rsplit('@', 1)
+    except (ValueError, AttributeError):
+        return None
+    return '@'.join([email_name.lower(), domain_part.lower()])
+
+
+def normalize_username(username: str) -> str:
+    return unicodedata.normalize('NFKC', username) if username else username
+
+
+def pluralize(value: int, one: str, two: str, five: str) -> str:
+    ones = value % 10
+    tens = value % 100
+    return one if (ones == 1 and tens != 11) else two if (2 <= ones <= 4 and (tens < 10 or tens >= 20)) else five
